"use client";

import {Card, CardContent} from "@/components/ui/card";
import {Popover, PopoverContent, PopoverTrigger} from "@/components/ui/popover";

import {BsFillPersonFill} from "react-icons/bs";
import {IoBed} from "react-icons/io5";
import {FaShower} from "react-icons/fa";
import parse, {domToReact} from "html-react-parser";
import {RiInformationLine} from "react-icons/ri";
import {AiOutlineLoading3Quarters} from "react-icons/ai";
import {Button} from "../ui/button";
import {useState} from "react";
import Image from "next/image";

interface Props {
  result: any;
  loadingCheck: boolean;
  openForm: () => void;
  cancelForm: () => void;
}
const ResultForm = ({result, loadingCheck, openForm, cancelForm}: Props) => {
  const [openCancel, setOpenCancel] = useState(false);
  const BookNow = () => {
    openForm();
    setOpenCancel(true);
  };

  const cancelBtn = () => {
    setOpenCancel(false);
    cancelForm();
  };
  const options = {
    replace: (node: any) => {
      if (!node.attribs) {
        return;
      }

      if (node.name === "p") {
        return <p>{domToReact(node.children, options)}</p>;
      }
    },
  };

  if (result && result.success) {
    return (
      <Card className="h-full rounded-none">
        <CardContent className="p-6 h-full relative">
          {loadingCheck && (
            <div className="absolute top-0 left-0 w-full h-full bg-white">
              <div className="flex items-center justify-center h-full w-full">
                <AiOutlineLoading3Quarters className="animate-spin h-16 w-16 text-main" />
              </div>
            </div>
          )}
          <div className="grid grid-cols-1 lg:grid-cols-3 gap-5 h-full w-full">
            <div className="w-full">
              <Image
              src="/pool/pool-7.webp"
              alt="Villa Batu"
                width={320}
                height={320}
                loading="eager"
                className="object-cover rounded-none h-full w-full"
              />
            </div>
            <div className="lg:col-span-2 flex flex-col justify-between gap-3">
              <h3 className="text-xl underline underline-offset-4 text-main">
                Stays From : {result.data.date}
              </h3>
              <div className="flex items-center gap-2">
                <span className="font-bold leading-loose text-black lg:text-xl text-sm">
                  USD {result.data.usd.toLocaleString("us-US")}
                </span>
                <Popover>
                  <PopoverTrigger>
                    <RiInformationLine />
                  </PopoverTrigger>
                  <PopoverContent
                    side="right"
                    align="center"
                    className="w-auto"
                  >
                    <span className="text-base font-bold">
                      Rp. {result.data.idr.toLocaleString("id-ID")}
                    </span>
                  </PopoverContent>
                </Popover>
              </div>
              <span>{result.data.night}</span>
              <div className="flex items-center gap-2">
                <span className="text-sm">View price details</span>
                <Popover>
                  <PopoverTrigger>
                    <RiInformationLine />
                  </PopoverTrigger>
                  <PopoverContent
                    side="right"
                    align="center"
                    className="w-auto"
                  >
                    <div className="space-y-2">
                      {/* {result.data.price_perday.map((item: any, index: any) => (
                        <div key={index} className="flex items-center gap-x-3">
                          <span className="text-sm">{item.date}</span>
                          <span className="text-sm">{item.price}</span>
                        </div>
                      ))} */}
                      {result.data.price_perday
                        .slice(0, -1)
                        .map((item: any, index: any) => (
                          <div
                            key={index}
                            className="flex items-center gap-x-3"
                          >
                            <span className="text-sm">{item.date}</span>
                            <span className="text-base font-bold">
                              ${item.price}
                            </span>
                          </div>
                        ))}
                    </div>
                  </PopoverContent>
                </Popover>
              </div>
              <div className="w-full">
                {openCancel ? (
                  <Button
                    className="w-full bg-main hover:bg-main/80"
                    onClick={cancelBtn}
                  >
                    Cancel
                  </Button>
                ) : (
                  <Button
                    className="w-full bg-main hover:bg-main/80"
                    onClick={BookNow}
                  >
                    Book Now
                  </Button>
                )}
              </div>
            </div>
          </div>
        </CardContent>
      </Card>
    );
  }

  return (
    <Card className="h-full rounded-none">
      <CardContent className="p-6 h-full relative">
        {loadingCheck && (
          <div className="absolute top-0 left-0 w-full h-full bg-white">
            <div className="flex items-center justify-center h-full w-full">
              <AiOutlineLoading3Quarters className="animate-spin h-16 text-main w-16" />
            </div>
          </div>
        )}
        <div className="grid grid-cols-1 lg:grid-cols-3 gap-5 h-full w-full">
          <div className="w-full">
            <Image
              src="/pool/pool-7.webp"
              alt="Villa Batu"
              width={320}
              height={320}
              loading="eager"
              className="object-cover rounded-none h-full w-full"
            />
          </div>

          <div className="lg:col-span-2 flex flex-col justify-center gap-3">
            <h3 className="text-xl  font-medium text-main">
            Please Select Dates To See The Price
            </h3>
            <div className="line-clamp-3 ">
              <p className="text-black">
              Villa Batu, a brand-new luxurious 4-bed retreat between Canggu and Seminyak, steps away from the beach. Book directly with us!
              </p>
            </div>
            <ul className="flex items-center gap-3 text-main">
              <li className="flex items-center">
                <BsFillPersonFill className="mr-2" />
                <span className="align-middle text-sm">8</span>
              </li>
              <li className="flex items-center">
                <IoBed className="mr-2" />
                <span className="align-middle text-sm">4</span>
              </li>
              <li className="flex items-center">
                <FaShower className="mr-2" />
                <span className="align-middle text-sm">4</span>
              </li>
            </ul>
          </div>
        </div>
      </CardContent>
    </Card>
  );
};

export default ResultForm;
